package cc.fascinated.model.user.history;

import lombok.Getter;
import lombok.Setter;

/**
 * @author Fascinated (fascinated7)
 */
@Getter
@Setter
public class HistoryPoint {
    // These are data points that are provided by ScoreSaber, and may not always be here

    /**
     * The rank of the player.
     */
    private Integer rank;

    /**
     * The pp of the player.
     */
    private Integer countryRank;

    /**
     * The pp of the player.
     */
    private Double pp;

    // Below are data points that are provided by us, therefore they will always be here

    /**
     * Play count of all the player's scores.
     */
    private Integer totalPlayCount;

    /**
     * Play count of all the player's ranked scores.
     */
    private Integer totalRankedPlayCount;

    /**
     * Play count of all the player's unranked scores.
     */
    private Integer totalUnrankedPlayCount;

    /**
     * Play count for this day's unranked scores.
     */
    private Integer unrankedPlayCount = 0;

    /**
     * Play count for this day's ranked scores.
     */
    private Integer rankedPlayCount = 0;

    /**
     * Whether the data for this day is possibly inaccurate.
     */
    private Boolean possiblyInaccurateData;

    /**
     * Gets whether the data for this day is possibly inaccurate.
     * <p>
     * eg: the user isn't having their data tracked every day
     * by us, only when they set a score
     * This will only affect rank, countryRank, and pp
     * </p>
     *
     * @return true if the data is possibly inaccurate, false otherwise
     */
    public Boolean getPossiblyInaccurateData() {
        return possiblyInaccurateData == null || possiblyInaccurateData;
    }

    /**
     * Increment the total ranked play count for this day.
     */
    public void incrementRankedPlayCount() {
        rankedPlayCount++;
    }

    /**
     * Increment the total unranked play count for this day.
     */
    public void incrementUnrankedPlayCount() {
        unrankedPlayCount++;
    }
}
